@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2009, 2010, 2013, 2014, 2015 kaliko <kaliko@azylum.org>
+# Copyright (c) 2009, 2010, 2013, 2014, 2015, 2021 kaliko <kaliko@azylum.org>
 #
 #  This file is part of sima
 #
@@ -26,16 +26,14 @@ Logging facility for sima.
 import logging
 import sys
 
-from os import environ
+from os import getenv
 
 DEBUG = logging.DEBUG
 INFO = logging.INFO
 ERROR = logging.ERROR
 LOG_FORMATS = {
-        DEBUG: '[{process}]{filename: >11}:{lineno: <3} {levelname: <7}: {message}',
+        DEBUG: '[{process}]{filename: >12}:{lineno: <3} {levelname: <7}: {message}',
         INFO:  '{levelname: <7}: {message}',
-        #logging.DEBUG: '{asctime} {filename}:{lineno}({funcName}) '
-                                 #'{levelname}: {message}',
         }
 DATE_FMT = "%Y-%m-%d %H:%M:%S"
 
@@ -56,7 +54,7 @@ def set_logger(level='info', logfile=None):
         logfile: file to log to
     """
     name = 'sima'
-    if environ.get('TRACE', False):
+    if getenv('TRACE', None):
         user_log_level = TRACE_LEVEL_NUM
     else:
         user_log_level = getattr(logging, level.upper())
@@ -80,7 +78,7 @@ def set_logger(level='info', logfile=None):
         if filehdl:
             logger.handlers = []
         # Add timestamp for file handler
-        log_format = '{0} {1}'.format('{asctime}', log_format)
+        log_format = f'{{asctime}} {log_format}'
         formatter = logging.Formatter(log_format, DATE_FMT, '{')
         # create file handler
         fileh = logging.FileHandler(logfile)
