@@ -103,7 +103,7 @@ class WebService(AdvancedPlugin):
             dynamic = 100
         results = []
         similarities.reverse()
-        while (len(results) < dynamic and similarities):
+        while (len(results) < dynamic+1 and similarities):
             art_pop = similarities.pop()
             res = self.player.search_artist(art_pop)
             if res:
@@ -123,7 +123,7 @@ class WebService(AdvancedPlugin):
         except WSNotFound as err:
             self.log.warning('%s: %s', self.ws.name, err)
             if artist.mbid:
-                self.log.debug('Trying without MusicBrainzID')
+                self.log.info('Trying without MusicBrainzID')
                 try:
                     return self.ws_similar_artists(Artist(name=artist.name))
                 except WSNotFound as err:
